@@ -260,12 +260,10 @@ uGlobalMenu::CanOpen()
     
   bool isVisible = dbusmenu_menuitem_property_get_bool(mDbusMenuItem,
                                                        DBUSMENU_MENUITEM_PROP_VISIBLE);
-  bool isDisabled = mContent->AttrValueIs(kNameSpaceID_None,
-                                          uWidgetAtoms::disabled,
-                                          uWidgetAtoms::_true,
-                                          eCaseMatters);
+  nsAutoString disabled;
+  mContent.AsElement()->GetAttribute(NS_LITERAL_STRING("disabled"), disabled);
 
-  return (isVisible && !isDisabled);
+  return (isVisible && !disabled.Equals(NS_LITERAL_STRING("true")));
 }
 
 void
