@@ -385,7 +385,7 @@ uGlobalMenuItem::SyncAccelFromContent()
   }
 
   nsAutoString modStr;
-  mKeyContent->GetAttr(kNameSpaceID_None, uWidgetAtoms::modifiers, modStr);
+  mKeyContent.AsElement()->GetAttribute(NS_LITERAL_STRING("modifiers"), modStr);
 
   PRUint32 modifier = 0;
 
@@ -422,7 +422,7 @@ uGlobalMenuItem::SyncAccelFromContent()
 
   nsAutoString keyStr;
   guint key = 0;
-  mKeyContent->GetAttr(kNameSpaceID_None, uWidgetAtoms::key, keyStr);
+  mKeyContent.AsElement()->GetAttribute(NS_LITERAL_STRING("key"), keyStr);
 
   nsAutoCString cKeyStr;
   CopyUTF16toUTF8(keyStr, cKeyStr);
@@ -436,7 +436,7 @@ uGlobalMenuItem::SyncAccelFromContent()
   }
 
   if (key == 0) {
-    mKeyContent->GetAttr(kNameSpaceID_None, uWidgetAtoms::keycode, keyStr);
+    mKeyContent.AsElement()->GetAttribute(NS_LITERAL_STRING("keycode"), keyStr);
     if (!keyStr.IsEmpty())
       key = MozKeyCodeToGdkKeyCode(GetKeyCode(keyStr));
   }
@@ -459,10 +459,10 @@ uGlobalMenuItem::SyncStateFromCommand()
 {
   TRACETM()
 
-  nsAutoString checked;
-  if (mCommandContent && mCommandContent->GetAttr(kNameSpaceID_None,
-                                                  uWidgetAtoms::checked,
-                                                  checked)) {
+  bool has = false;
+  if (mCommandContent && NS_SUCCEEDED(mCommandContent.AsElement()->HasAttribute(NS_LITERAL_STRING("checked"), &has)) && has) {
+    nsAutoString checked;
+    mCommandContent.AsElement()->GetAttribute(NS_LITERAL_STRING("checked"), checked);
     LOGTM("Copying checked state from command node");
     mContent->SetAttr(kNameSpaceID_None, uWidgetAtoms::checked, checked,
                       true);
@@ -474,10 +474,10 @@ uGlobalMenuItem::SyncLabelFromCommand()
 {
   TRACETM()
 
-  nsAutoString label;
-  if (mCommandContent && mCommandContent->GetAttr(kNameSpaceID_None,
-                                                  uWidgetAtoms::label,
-                                                  label)) {
+  bool has = false;
+  if (mCommandContent && NS_SUCCEEDED(mCommandContent.AsElement()->HasAttribute(NS_LITERAL_STRING("label"), &has)) && has) {
+    nsAutoString label;
+    mCommandContent.AsElement()->GetAttribute(NS_LITERAL_STRING("label"), label);
     LOGTM("Copying label from command node");
     mContent->SetAttr(kNameSpaceID_None, uWidgetAtoms::label, label,
                       true);
@@ -490,8 +490,9 @@ uGlobalMenuItem::SyncSensitivityFromCommand()
   TRACETM()
 
   if (mCommandContent) {
-    if (mCommandContent->AttrValueIs(kNameSpaceID_None, uWidgetAtoms::disabled,
-                                     uWidgetAtoms::_true, eCaseMatters)) {
+    nsAutoString disabled;
+    mCommandContent.AsElement()->GetAttribute(NS_LITERAL_STRING("disabled"), disabled);
+    if (disabled.Equals(NS_LITERAL_STRING("true"))) {
       mContent->SetAttr(kNameSpaceID_None, uWidgetAtoms::disabled,
                         NS_LITERAL_STRING("true"), true);
     } else {
@@ -509,8 +510,10 @@ uGlobalMenuItem::SyncStateFromContent()
     return;
   }
 
-  SetCheckState(mContent->AttrValueIs(kNameSpaceID_None, uWidgetAtoms::checked,
-                                      uWidgetAtoms::_true, eCaseMatters));
+  nsAutoString checked;
+  mContent.AsElement()->GetAttribute(NS_LITERAL_STRING("checked"), checked);
+  SetCheckState(checked.Equals(NS_LITERAL_STRING("true")));
+
   dbusmenu_menuitem_property_set_int(mDbusMenuItem,
                                      DBUSMENU_MENUITEM_PROP_TOGGLE_STATE,
                                      IsChecked() ?
@@ -590,7 +593,7 @@ uGlobalMenuItem::Refresh(uMenuObjectRefreshMode aMode)
       NS_ASSERTION(domDoc, "nsIDocument failed QI to nsIDOMDocument");
       if (domDoc) {
         nsAutoString value;
-        mContent->GetAttr(kNameSpaceID_None, uWidgetAtoms::command, value);
+        mContent.AsElement()->GetAttribute(NS_LITERAL_STRING("command"), value);
         if (!value.IsEmpty()) {
           nsCOMPtr<nsIDOMElement> elem;
           domDoc->GetElementById(value, getter_AddRefs(elem));
@@ -601,7 +604,7 @@ uGlobalMenuItem::Refresh(uMenuObjectRefreshMode aMode)
             }
           }
         }
-        mContent->GetAttr(kNameSpaceID_None, uWidgetAtoms::key, value);
+        mContent.AsElement()->GetAttribute(NS_LITERAL_STRING("key"), value);
         if (!value.IsEmpty()) {
           nsCOMPtr<nsIDOMElement> elem;
           domDoc->GetElementById(value, getter_AddRefs(elem));
@@ -658,8 +661,9 @@ uGlobalMenuItem::Activate(PRUint32 timeStamp)
 
   // XXX: it is important to update the checkbox state before dispatching
   //      the event, as the handler might check the new state
-  if (!mContent->AttrValueIs(kNameSpaceID_None, uWidgetAtoms::autocheck,
-                             uWidgetAtoms::_false, eCaseMatters) &&
+  nsAutoString autocheck;
+  mContent.AsElement()->GetAttribute(NS_LITERAL_STRING("autocheck"), autocheck);
+  if (!autocheck.Equals(NS_LITERAL_STRING("false")) &&
       (GetMenuItemType() == eCheckBox ||
        (GetMenuItemType() == eRadio && !IsChecked()))) {
     mContent->SetAttr(kNameSpaceID_None, uWidgetAtoms::checked,
@@ -753,7 +757,7 @@ uGlobalMenuItem::UncheckSiblings()
   }
 
   nsAutoString name;
-  mContent->GetAttr(kNameSpaceID_None, uWidgetAtoms::name, name);
+  mContent.AsElement()->GetAttribute(NS_LITERAL_STRING("name"), name);
 
   nsIContent *parent = mContent->GetParent();
   if (!parent) {
@@ -762,15 +766,17 @@ uGlobalMenuItem::UncheckSiblings()
 
   PRUint32 count = parent->GetChildCount();
   for (PRUint32 i = 0; i < count; i++) {
-    nsIContent *sibling = parent->GetChildAt(i);
+    nsIContentWrapper sibling = parent->GetChildAt(i);
 
     nsAutoString otherName;
-    sibling->GetAttr(kNameSpaceID_None, uWidgetAtoms::name, otherName);
+    sibling.AsElement()->GetAttribute(NS_LITERAL_STRING("name"), otherName);
 
-    if (sibling != mContent && otherName == name && 
-        sibling->AttrValueIs(kNameSpaceID_None, uWidgetAtoms::type,
-                             uWidgetAtoms::radio, eCaseMatters)) {
-      sibling->UnsetAttr(kNameSpaceID_None, uWidgetAtoms::checked, true);
+    if (sibling != mContent && otherName == name) {
+      nsAutoString type;
+      sibling.AsElement()->GetAttribute(NS_LITERAL_STRING("type"), type);
+      if (type.Equals(NS_LITERAL_STRING("radio"))) { 
+        sibling->UnsetAttr(kNameSpaceID_None, uWidgetAtoms::checked, true);
+      }
     }
   }
 }
@@ -848,10 +854,13 @@ uGlobalMenuItem::ObserveAttributeChanged(nsIContent *aContent,
                aContent == mKeyContent,
                "Received an event that wasn't meant for us!");
 
-  if (aContent == mContent && aAttribute == uWidgetAtoms::checked &&
-      aContent->AttrValueIs(kNameSpaceID_None, uWidgetAtoms::checked,
-                            uWidgetAtoms::_true, eCaseMatters)) {
-    UncheckSiblings();
+  if (aContent == mContent && aAttribute == uWidgetAtoms::checked) {
+    nsAutoString checked;
+    nsCOMPtr<nsIDOMElement> elem = do_QueryInterface(aContent);
+    elem->GetAttribute(NS_LITERAL_STRING("checked"), checked);
+    if (checked.Equals(NS_LITERAL_STRING("true"))) {
+      UncheckSiblings();
+    }
   }
 
   if (aContent == mContent) {
