@@ -149,9 +149,9 @@ uGlobalMenuObject::IconLoader::LoadIcon()
   }
 
   nsAutoString uriString;
-  bool hasImage = mMenuItem->GetContent()->GetAttr(kNameSpaceID_None,
-                                                   uWidgetAtoms::image,
-                                                   uriString);
+  mMenuItem->GetContent().AsElement()->GetAttribute(NS_LITERAL_STRING("image"),
+                                                    uriString);
+  bool hasImage = !uriString.IsEmpty();
 
   nsresult rv;
   nsCOMPtr<nsIDOMRect> domRect;
@@ -553,7 +553,7 @@ uGlobalMenuObject::ShouldShowIcon()
   }
 
   nsAutoString value;
-  mContent->GetAttr(kNameSpaceID_None, uWidgetAtoms::_class, value);
+  mContent.AsElement()->GetAttribute(NS_LITERAL_STRING("class"), value);
 
   const PRUnichar *iter = value.BeginReading();
   const PRUnichar *end = value.EndReading();
@@ -565,9 +565,9 @@ uGlobalMenuObject::ShouldShowIcon()
 
     const PRUnichar *start = iter;
 
-    do {
+    while (iter != end && !IsHTMLWhitespace(*iter)) {
       ++iter;
-    } while (iter != end && !IsHTMLWhitespace(*iter));
+    };
 
     const nsDependentSubstring& sub = Substring(start, iter);
 
@@ -588,10 +588,10 @@ uGlobalMenuObject::SyncLabelFromContent()
   // label="_Foo" for dbusmenu
 
   nsAutoString label;
-  mContent->GetAttr(kNameSpaceID_None, uWidgetAtoms::label, label);
+  mContent.AsElement()->GetAttribute(NS_LITERAL_STRING("label"), label);
 
   nsAutoString accesskey;
-  mContent->GetAttr(kNameSpaceID_None, uWidgetAtoms::accesskey, accesskey);
+  mContent.AsElement()->GetAttribute(NS_LITERAL_STRING("accesskey"), accesskey);
 
   const PRUnichar *tmp = accesskey.BeginReading();
   nsICaseConversion *converter = uGlobalMenuService::GetCaseConverter();
@@ -714,10 +714,10 @@ uGlobalMenuObject::SyncSensitivityFromContent()
 {
   TRACETM();
 
-  bool disabled = mContent->AttrValueIs(kNameSpaceID_None,
-                                        uWidgetAtoms::disabled,
-                                        uWidgetAtoms::_true,
-                                        eCaseMatters);
+  nsAutoString value;
+  mContent.AsElement()->GetAttribute(NS_LITERAL_STRING("disabled"), value);
+  bool disabled = value.Equals(NS_LITERAL_STRING("true"));
+
   LOGTM("Setting %s", disabled ? "disabled" : "enabled");
 
   dbusmenu_menuitem_property_set_bool(mDbusMenuItem,
